#include "project.h"
#include "stdio.h"

#if 1 // change to 0 if your LED turn on with LOW LEVEL
#define LED_ON (1u)
#define LED_OFF (0u) 
#else
#define LED_ON (0u)
#define LED_OFF (1u)
#endif


#define STR_LEN 64
char str[STR_LEN+1] ; /* print buffer */
void print(char *str)
{
    UART_UartPutString(str) ;
}

void cls(void)
{
    print("\033c") ; /* reset */
    CyDelay(20) ;
    print("\033[2J") ; /* clear screen */
    CyDelay(20) ;
}

void splash(void)
{
    cls() ;

    sprintf(str, "CapSense Test (%s %s)\n", __DATE__, __TIME__) ;
    print(str) ;

    snprintf(str, STR_LEN, "(%s %s)\n", __DATE__, __TIME__) ;
    print(str) ;
}

void init_hardware(void)
{
    CyGlobalIntEnable; /* Enable global interrupts. */

    UART_Start() ;
    
    CapSense_Start() ;
    CapSense_ScanAllWidgets() ;
}

int main(void)
{
    uint32_t button_state = 0 ;
    uint32_t proximity_state = 0 ;
    
    init_hardware() ;
    
    splash() ;

    for(;;)
    {
        if (CapSense_IsBusy() == CapSense_NOT_BUSY) {
            CapSense_ProcessAllWidgets() ;
            
            button_state = CapSense_IsSensorActive(
                CapSense_BUTTON0_WDGT_ID,
                CapSense_BUTTON0_SNS0_ID
            ) ;
            if (button_state) { /* button pressed */
                LED1_Write(LED_ON) ;
                snprintf(str, STR_LEN, "Button1: 0x%08X\n", button_state) ;
                print(str) ;
            } else {
                LED1_Write(LED_OFF) ;
            }
            button_state = CapSense_IsSensorActive(
                CapSense_BUTTON0_WDGT_ID,
                CapSense_BUTTON0_SNS1_ID
            ) ;
            if (button_state) { /* button pressed */
                LED2_Write(LED_ON) ;
                snprintf(str, STR_LEN, "Button2: 0x%08X\n", button_state) ;
                print(str) ;
            } else {
                LED2_Write(LED_OFF) ;
            }
            button_state = CapSense_IsSensorActive(
                CapSense_BUTTON0_WDGT_ID,
                CapSense_BUTTON0_SNS2_ID
            ) ;
            if (button_state) { /* button pressed */
                LED3_Write(LED_ON) ;
                snprintf(str, STR_LEN, "Button3: 0x%08X\n", button_state) ;
                print(str) ;
            } else {
                LED3_Write(LED_OFF) ;
            }
            button_state = CapSense_IsSensorActive(
                CapSense_BUTTON0_WDGT_ID,
                CapSense_BUTTON0_SNS3_ID
            ) ;
            if (button_state) { /* button pressed */
                LED4_Write(LED_ON) ;
                snprintf(str, STR_LEN, "Button4: 0x%08X\n", button_state) ;
                print(str) ;
            } else {
                LED4_Write(LED_OFF) ;
            }
            
            proximity_state = CapSense_IsSensorActive(
                CapSense_PROXIMITY0_WDGT_ID,
                CapSense_PROXIMITY0_SNS0_ID
            ) ;
            if (proximity_state) {
                snprintf(str, STR_LEN, "Proximity: 0x%08X\n", proximity_state) ;
                print(str) ;
            }
            CapSense_ScanAllWidgets();  
        }
            
    }
}

